@@ -1,4 +1,4 @@
-/* $Id: command.h,v 1.29 2003/10/20 20:11:58 hadess Exp $ */
+/* $Id: command.h,v 1.30 2004/07/18 20:33:55 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -82,7 +82,7 @@ union _glibtop_response_union
 
 struct _glibtop_response
 {
-	int64_t offset;
+	gint64 offset;
 	guint64 size, data_size;
 	glibtop_response_union u;
 };
