@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id: write.h,v 1.8 1999/03/30 14:23:41 martin Exp $ */
+/* $Id: write.h,v 1.11 2003/10/20 15:19:39 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -29,13 +27,13 @@
 #include <glibtop.h>
 #include <glibtop/error.h>
 
-BEGIN_LIBGTOP_DECLS
+G_BEGIN_DECLS
 
 #define glibtop_write(p1, p2)	glibtop_write(glibtop_global_server, p1, p2)
 
 void glibtop_write_l (glibtop *server, size_t size, void *buf);
 void glibtop_write_s (glibtop *server, size_t size, void *buf);
 
-END_LIBGTOP_DECLS
+G_END_DECLS
 
 #endif
